@@ -1,12 +1,68 @@
 #include "sdl4gcj/video/PixelFormat.h"
 #include "sdl4gcj/video/Color.h"
 #include "sdl4gcj/video/Palette.h"
+#include "sdl4gcj/SDLException.h"
 
 #include <gcj/cni.h>
 #include <SDL.h>
+#include <stdlib.h>
 
 using namespace sdl4gcj::video;
 
+// function
+static
+SDL_PixelFormat*
+CloneFormat(SDL_PixelFormat *format)
+{
+	SDL_PixelFormat* cloneFormat = NULL;
+	if (format)
+	{
+		cloneFormat = (SDL_PixelFormat*)JvMalloc(sizeof(SDL_PixelFormat));
+		*cloneFormat = *format;
+		if (format->palette)
+		{
+			int ncolors = format->palette->ncolors;
+			cloneFormat->palette = (SDL_Palette*)JvMalloc(sizeof(SDL_Palette));
+			cloneFormat->palette->ncolors = ncolors;
+			if (format->palette->colors)
+			{
+				jint size = sizeof(SDL_Color) * ncolors;
+				cloneFormat->palette->colors = (SDL_Color*)JvMalloc(size);
+				memcpy(cloneFormat->palette->colors, format->palette->colors, size);
+			}
+		}
+	}
+	return cloneFormat;
+}
+
+static
+void
+FreeFormat(SDL_PixelFormat *format)
+{
+	if (format)
+	{
+		if (format->palette)
+		{
+			if (format->palette->colors)
+			{
+				JvFree(format->palette->colors);
+			}
+			JvFree(format->palette);
+		}
+		JvFree(format);
+	}
+}
+
+
+static
+inline
+sdl4gcj::SDLException*
+createInitializedFormatException()
+{
+	return new sdl4gcj::SDLException(JvNewStringLatin1("This Surface was already initialized."));
+}
+
+// instance variable
 jbyte 
 PixelFormat::getBitsPerPixel ()
 {
@@ -236,3 +292,32 @@ PixelFormat::getPalette ()
 	return palette;
 }
 
+void
+PixelFormat::initWithMask(jint depth,
+		jint rmask, jint gmask, jint bmask, jint amask)
+{
+	if (this->implementation != NULL)
+		throw createInitializedFormatException();
+
+	SDL_Surface* tmpSurface;
+	tmpSurface = SDL_CreateRGBSurface(SDL_SWSURFACE,
+		1, 1, depth, rmask, gmask, bmask, amask);
+
+	SDL_PixelFormat* nativeFormat = CloneFormat(tmpSurface->format);
+	this->implementation = (::gnu::gcj::RawData*)nativeFormat;
+	this->selfAllocated = true;
+
+	SDL_FreeSurface(tmpSurface);
+}
+
+void
+PixelFormat::freePixelFormat()
+{
+	if (this->selfAllocated && this->implementation != NULL)
+	{
+		SDL_PixelFormat* nativeFormat = (SDL_PixelFormat*)this->implementation;
+		FreeFormat(nativeFormat);
+		this->implementation = NULL;
+	}
+}
+
