@@ -1,6 +1,8 @@
 #include "sdl4gcj/video/Screen.h"
+#include "sdl4gcj/video/PixelFormat.h"
 #include "sdl4gcj/video/VideoInfo.h"
 #include "sdl4gcj/video/Rect.h"
+#include "sdl4gcj/video/Rectangle.h"
 #include "sdl4gcj/SDLException.h"
 
 #include <java/lang/String.h>
@@ -31,6 +33,38 @@ createIllegalStateScreenException()
 }
 
 // class methods
+JArray<Rect *> *
+Screen::listModes (::sdl4gcj::video::PixelFormat *format, jint flags)
+{
+	fprintf(stderr, "hello\n");
+	JvInitClass(&Screen::class$);
+	JArray<Rect *> *modeArray = NULL;
+
+	SDL_PixelFormat* nativeFormat = NULL;
+	if (format != NULL)
+		nativeFormat = (SDL_PixelFormat*)format->implementation;
+
+	SDL_Rect** nativeModes = SDL_ListModes(nativeFormat, flags);
+	if (nativeModes != NULL)
+	{
+		int length = 0;
+		if (nativeModes != (SDL_Rect**)-1)
+		{
+			while (nativeModes[length]) length++; 
+		}
+
+		modeArray = (JArray<Rect *> *)JvNewObjectArray(length, &Rect::class$, NULL);
+		Rect** modes = elements(modeArray);
+		for (int i = 0;i < length;i++)
+		{
+			modes[i] = (Rect*)new Rectangle(0, 0,
+				nativeModes[i]->w, nativeModes[i]->h);
+		}
+	}
+
+	return modeArray;
+}
+
 jint
 Screen::videoModeOK(jint width, jint height, jint bpp, jint flags)
 {
