@@ -445,19 +445,19 @@ public class Surface implements VideoConstants
 		super.finalize();
 	}
 
-	protected native void initRGBSurface(int flags, 
+	private native void initRGBSurface(int flags, 
 		int width, int height, int bpp,
 		int rmask, int gmask, int bmask, int amask);
 
-	protected native void initRGBSurfaceFrom(byte[] pixels,
+	private native void initRGBSurfaceFrom(byte[] pixels,
 		int width, int height, int bpp, int pitch,
 		int rmask, int gmask, int bmask, int amask);
 
-	protected native void initRGBSurfaceFrom(short[] pixels,
+	private native void initRGBSurfaceFrom(short[] pixels,
 		int width, int height, int bpp, int pitch,
 		int rmask, int gmask, int bmask, int amask);
 
-	protected native void initRGBSurfaceFrom(int[] pixels,
+	private native void initRGBSurfaceFrom(int[] pixels,
 		int width, int height, int bpp, int pitch,
 		int rmask, int gmask, int bmask, int amask);
 
