@@ -1,9 +1,12 @@
 #include "sdl4gcj/video/Surface.h"
+
 #include "sdl4gcj/video/PixelFormat.h"
 #include "sdl4gcj/video/Color.h"
 #include "sdl4gcj/video/Palette.h"
 #include "sdl4gcj/SDLException.h"
 
+#include <java/lang/IndexOutOfBoundsException.h>
+
 #include <gcj/cni.h>
 #include <java/lang/String.h>
 #include <stdlib.h>
@@ -30,6 +33,14 @@ createSmallPixelArrayException()
 	return new sdl4gcj::SDLException(JvNewStringLatin1("Pixels array is too small."));
 }
 
+static
+inline
+java::lang::IndexOutOfBoundsException*
+createIndexOutOfBoundsException()
+{
+	return new java::lang::IndexOutOfBoundsException(JvNewStringLatin1("Palette Index Out of Bounds"));
+}
+
 // class methods
 ::java::lang::String*
 Surface::getVideoDriverName()
@@ -314,7 +325,7 @@ Surface::displayFormat ()
 }
 
 void
-Surface::displayForamtAlpha ()
+Surface::displayFormatAlpha ()
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* nativeSurface = (SDL_Surface*)this->implementation;
@@ -400,17 +411,16 @@ Surface::setPalette (JArray< Color *> *palette)
 }
 
 void 
-Surface::setPalette (Palette *palette)
+Surface::setPalette (Palette *palette, jint index, jint firstcolor, jint ncolors)
 {
 	if (this->implementation == NULL) throw createFreedSurfaceException();
 	SDL_Surface* nativeSurface = (SDL_Surface*)this->implementation;
-
 	if (nativeSurface->format->palette != NULL)
 	{
+		if (index < 0 && index > (palette->getSize() - ncolors))
+			throw createIndexOutOfBoundsException();
 		SDL_Color* nativeColors = (SDL_Color*)palette->colors;
-		int ncolors = palette->getSize();
-		ncolors = ncolors <= 256 ? ncolors : 256;
-		SDL_SetColors(nativeSurface, nativeColors, 0, ncolors);
+		SDL_SetColors(nativeSurface, &nativeColors[index], firstcolor, ncolors);
 	}
 	return ;
 }
