@@ -35,7 +35,7 @@ public class TestGL extends GL implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (Sys.init(Sys.SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
@@ -61,7 +61,7 @@ public class TestGL extends GL implements SDLConstants
 			int frames = 0;
 			boolean done = false;
 			EventManager event = new EventManager();
-			long totalTicks = Sys.getTicks();
+			long totalTicks = SDLSystem.getTicks();
 			while (!done)
 			{
 				while (event.pollEvent() > 0)
@@ -86,10 +86,10 @@ public class TestGL extends GL implements SDLConstants
 				y_angle = (y_angle + 1) % 360;
 				display();
 				screen.glSwapBuffers();
-				Sys.delay(20);
+				SDLSystem.delay(20);
 			}
 
-			totalTicks = Sys.getTicks() - totalTicks;
+			totalTicks = SDLSystem.getTicks() - totalTicks;
 			System.out.println(((double)frames * 1000) / totalTicks + " (Frame per Second)");
 		}
 		catch (Exception e)
@@ -98,7 +98,7 @@ public class TestGL extends GL implements SDLConstants
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
