@@ -10,9 +10,9 @@ public class ImageFontTest implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (Sys.init(SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
-			System.out.println("Sys#init() fail.");
+			System.out.println(SDLException.getError());
 			System.exit(0);
 		}
 		
@@ -79,6 +79,6 @@ public class ImageFontTest implements SDLConstants
 			}
 		}
 
-		Sys.quit();
+		SDLSystem.quit();
 	}
 }
