@@ -75,7 +75,7 @@ public class MouseTest implements SDLConstants
 //		message.append(mouse.getRelativeY());
 //		font.draw(screen, message, x, y);
 
-		screen.updateRect();
+		screen.flip();
 	}
 	
 	public void initialize()
@@ -83,12 +83,15 @@ public class MouseTest implements SDLConstants
 		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail.");
+			System.out.println(SDLException.getError());
+			
 			System.exit(0);
 		}
-		screen = Screen.setVideoMode(640, 480, 16, SDL_SWSURFACE|SDL_ANYFORMAT);
+		screen = Screen.setVideoMode(640, 480, 8, SDL_SWSURFACE|SDL_ANYFORMAT|SDL_DOUBLEBUF);
 		if (screen == null)
 		{
 			System.out.println("Screen.setVideoMode() fail.");
+			System.out.println(SDLException.getError());
 			System.exit(0);
 		}
 		bgPixel = screen.mapRGB(Color.BLACK);
