@@ -24,7 +24,7 @@ public class RepeatTest implements SDLConstants
 
 			// load background image
 			Surface bgTip = Surface.loadBMP(BG_IMAGE_PATH);
-			Surface bg = new Surface(SDL_SWSURFACE, 640, 480, 32, 0xff0000, 0xff00, 0xff, 0x00);
+			Surface bg = Surface.createRGBSurface(SDL_SWSURFACE, 640, 480, 32, 0xff0000, 0xff00, 0xff, 0x00);
 			bg.repeatSurface(bgTip);
 			bg.displayFormat();
 
@@ -32,7 +32,6 @@ public class RepeatTest implements SDLConstants
 			icon.setColorKey(SDL_SRCCOLORKEY|SDL_RLEACCEL);
 			icon.displayFormat();
 
-			// repeat blit bg
 			screen.blitSurface(bg);
 			screen.updateRect();
 
